==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/lt_LT.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Paskiausios būsenos",
    "In a meeting" : "Susitikime",
    "Commuting" : "Važinėju",
    "Out sick" : "Sergu",
    "Vacationing" : "Poilsiauju",
    "Working remotely" : "Dirbu nuotoliniu būdu",
    "User status" : "Naudotojo būsena",
    "Clear status message after" : "Išvalyti būsenos žinutę po",
    "What's your status?" : "Kokia jūsų būsena?",
    "Set status" : "Nustatyti būseną",
    "Online status" : "Prisijungimo būsena",
    "Status message" : "Būsenos žinutė",
    "Clear status message" : "Išvalyti būsenos žinutę",
    "Set status message" : "Nustatyti būsenos žinutę",
    "There was an error saving the status" : "Įrašant būseną, įvyko klaida",
    "There was an error clearing the status" : "Išvalant būseną, įvyko klaida",
    "No recent status changes" : "Jokių paskiausių būsenos pasikeitimų",
    "Away" : "Atsitraukęs",
    "Do not disturb" : "Netrukdyti",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Neišvalyti",
    "Today" : "Šiandien",
    "This week" : "Šią savaitę",
    "Online" : "Prisijungęs",
    "Invisible" : "Nematoma",
    "Offline" : "Atsijungęs",
    "There was an error saving the new status" : "Įrašant naują būseną, įvyko klaida",
    "30 minutes" : "30 minučių",
    "1 hour" : "1 valanda",
    "4 hours" : "4 valandos",
    "Mute all notifications" : "Išjungti visus pranešimus",
    "Appear offline" : "Atrodyti atsijungusiu",
    "Clear status after" : "Išvalyti būseną po"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-23.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/lt_LT.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Paskiausios būsenos",
    "In a meeting" : "Susitikime",
    "Commuting" : "Važinėju",
    "Out sick" : "Sergu",
    "Vacationing" : "Poilsiauju",
    "Working remotely" : "Dirbu nuotoliniu būdu",
    "User status" : "Naudotojo būsena",
    "Clear status message after" : "Išvalyti būsenos žinutę po",
    "What is your status?" : "Kokia jūsų būsena?",
    "Set status" : "Nustatyti būseną",
    "Online status" : "Prisijungimo būsena",
    "Status message" : "Būsenos žinutė",
    "Clear status message" : "Išvalyti būsenos žinutę",
    "Set status message" : "Nustatyti būsenos žinutę",
    "There was an error saving the status" : "Įrašant būseną, įvyko klaida",
    "There was an error clearing the status" : "Išvalant būseną, įvyko klaida",
    "No recent status changes" : "Jokių paskiausių būsenos pasikeitimų",
    "Away" : "Atsitraukęs",
    "Do not disturb" : "Netrukdyti",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Neišvalyti",
    "Today" : "Šiandien",
    "This week" : "Šią savaitę",
    "Online" : "Prisijungęs",
    "Invisible" : "Nematoma",
    "Offline" : "Atsijungęs",
    "There was an error saving the new status" : "Įrašant naują būseną, įvyko klaida",
    "30 minutes" : "30 minučių",
    "1 hour" : "1 valanda",
    "4 hours" : "4 valandos",
    "Mute all notifications" : "Išjungti visus pranešimus",
    "Appear offline" : "Atrodyti atsijungusiu",
    "Clear status after" : "Išvalyti būseną po",
    "What's your status?" : "Kokia jūsų būsena?"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
